<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
  xmlns="http://www.w3.org/1999/XSL/Format" 
  xmlns:in="urn:oasis:names:tc:ubl:Invoice:1.0:0.70" 
  xmlns:cat="urn:oasis:names:tc:ubl:CommonAggregateTypes:1.0:0.70">

<!--
Copyright (C) - Crane Softwrights Ltd. 
              - http://www.CraneSoftwrights.com/links/res-ubls.htm

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright notice, 
  this list of conditions and the following disclaimer. 
- Redistributions in binary form must reproduce the above copyright notice, 
  this list of conditions and the following disclaimer in the documentation 
  and/or other materials provided with the distribution. 
- The name of the author may not be used to endorse or promote products 
  derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN 
NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Note: for your reference, the above is the "Modified BSD license", this text
      was obtained 2002-12-16 at http://www.xfree86.org/3.3.6/COPYRIGHT2.html#5
-->

<!--Override this with a non-empty string to trigger HTML-orientation-->
<xsl:variable name="html-output"/>

<!--Override these A4 page dimensions with US-letter dimensions-->
<xsl:variable name="long-page-edge" select="'297mm'"/>
<xsl:variable name="short-page-edge" select="'210mm'"/>

<!--Set up the result-->
<xsl:template match="/">
   <root font-family="Times" font-size="12pt" line-height="1.1">
<!--check expected document element-->
      <xsl:if test="not(in:Invoice)">
         <xsl:message terminate="yes">
            <xsl:text>Unexpected instance for stylesheet:
{</xsl:text>
            <xsl:value-of select="namespace-uri(*)"/>
            <xsl:text>}</xsl:text>
            <xsl:value-of select="local-name(*)"/>
            <xsl:text>
Expecting:
{</xsl:text>
            <xsl:text>urn:oasis:names:tc:ubl:Invoice:1.0:0.70</xsl:text>
            <xsl:text>}Invoice</xsl:text>
         </xsl:message>
      </xsl:if>

<!--describe page geometries-->
      <layout-master-set>
         <simple-page-master master-name="onepage" 
              page-width="{$long-page-edge}" 
              page-height="{$short-page-edge}" 
              margin-top="20mm"
              margin-bottom="{$short-page-edge} - 20mm - 183mm" 
              margin-right="10mm"
              margin-left="{$long-page-edge} -20mm - 262mm">
            <region-body region-name="body" 
                 margin-left="10mm" margin-top="2.5cm" 
                 margin-bottom=".5cm"/>
            <region-before region-name="before" extent="2.5cm"/>
            <region-after region-name="after" extent=".5cm"/>
            <region-start region-name="start" extent="10mm"/>
         </simple-page-master>
         <page-sequence-master master-name="layout">
            <repeatable-page-master-reference master-reference="onepage"/>
         </page-sequence-master>
      </layout-master-set>
<!--process the data-->
      <xsl:apply-templates select="in:Invoice"/>
   </root>
</xsl:template>

<!--========================================================================-->

<!--Header Information-->

<xsl:template match="in:Invoice">
   <page-sequence master-reference="layout">
      <title>
         <xsl:value-of select="cat:ID"/>
         <xsl:text> - </xsl:text>
         <xsl:value-of select="cat:IssueDate"/>
         <xsl:text> - Invoice (Joinery)</xsl:text>
      </title>
      <xsl:call-template name="start-edge-marginalia"/>
      <xsl:call-template name="before-edge-marginalia"/>
      <xsl:call-template name="after-edge-marginalia"/>
      <flow flow-name="body">
         <block>
            <marker marker-class-name="cont">
               <xsl:text>(continued...)</xsl:text>
            </marker>
         </block>
         <table table-layout="fixed" width="100%">
            <table-column column-width="10%"/>
            <table-column column-width="26%"/>
            <table-column column-width="10%"/>
            <table-column column-width="26%"/>
            <table-column column-width="28%"/>
            <table-body>
               <table-row height="6em">
                  <table-cell height="6em">
                     <block-container height="6em">
                        <block>
                           <xsl:text>Buyer:</xsl:text>
                        </block>
                     </block-container>
                  </table-cell>
                  <table-cell height="6em">
                     <block-container height="6em">
                        <xsl:apply-templates select="cat:BuyerParty"/>
                     </block-container>
                  </table-cell>
                  <table-cell height="6em">
                     <block-container height="6em">
                        <block>
                           <xsl:text>Seller:</xsl:text>
                        </block>
                     </block-container>
                  </table-cell>
                  <table-cell height="6em">
                     <block-container height="6em">
                        <xsl:apply-templates select="cat:SellerParty"/>
                     </block-container>
                  </table-cell>
                  <table-cell height="6em">
                    <block-container height="6em">
                      <xsl:apply-templates 
                        select="cat:ReferencedDespatchAdvice/cat:ID"/>
                      <xsl:apply-templates
                               select="cat:ReferencedOrder/cat:BuyersOrderID"/>
                      <xsl:apply-templates
                               select="cat:ReferencedOrder/cat:IssueDate"/>
                    </block-container>
                  </table-cell>
               </table-row>
            </table-body>
         </table>
         <table table-layout="fixed" width="100%" space-before="1em">
            <table-column column-width="10%"/>
            <table-column column-width="26%"/>
            <table-column column-width="10%"/>
            <table-column column-width="26%"/>
            <table-column column-width="28%"/>
            <table-body>
               <table-row height="2em">
                  <table-cell height="2em">
                     <block-container height="2em">
                        <block>
                           <xsl:text>Contact:</xsl:text>
                        </block>
                     </block-container>
                  </table-cell>
                  <table-cell height="2em">
                     <block-container height="2em">
                        <xsl:apply-templates select="cat:BuyerParty/cat:BuyerContact/cat:Name"/>
                     </block-container>
                  </table-cell>
               </table-row>
            </table-body>
         </table>

         <!--act on only the first of all the dates-->
         <xsl:apply-templates select="(cat:InvoiceLine/cat:DeliveryRequirement/cat:DeliverySchedule/cat:RequestedDeliveryDate)[1]"/>

         <!--do all the line items in the table-->
         <xsl:call-template name="do-line-items"/>

         <!--text at bottom-->
         <block space-before="1em">
           <xsl:text>If paid within </xsl:text>
           <xsl:for-each 
            select="cat:PaymentTerms/cat:SettlementPeriod/cat:DurationMeasure">
             <xsl:value-of select="."/>
             <xsl:text> </xsl:text>
             <xsl:value-of select="@unitCode"/>
           </xsl:for-each>
           <xsl:variable name="discount"
          select="cat:PaymentTerms/cat:SettlementDiscountRateNumeric div 100"/>
        <xsl:text> of Invoice Date, a prompt settlement discount of </xsl:text>
           <xsl:value-of select="format-number( $discount, '0.0%' )"/>
           <xsl:text>, amount </xsl:text>
           <xsl:for-each select="cat:LegalTotals/cat:LineExtensionTotalAmount">
             <xsl:value-of select="@currencyID"/>
             <xsl:text>&#xa0;</xsl:text>
             <xsl:value-of 
                       select="format-number( . * $discount, '0.00')"/>
           </xsl:for-each>
           <xsl:text>, may be deducted from the TOTAL DUE.</xsl:text>
         </block>
         <block>
           <xsl:for-each select="cat:PaymentMeans/cat:PayeeFinancialAccount">
             <xsl:text>Payment should be made to the account "</xsl:text>
             <xsl:value-of select="cat:AccountName"/>
             <xsl:text>", account number </xsl:text>
             <xsl:value-of select="cat:ID"/>
             <xsl:text>, at bank/branch </xsl:text>
             <xsl:value-of select="cat:FiBranch/cat:ID"/>
             <xsl:text>.</xsl:text>
           </xsl:for-each>
         </block>

<!--meta data for this form in HTML-->
         <block font-family="Arial" font-size="6pt" text-indent="8mm">
            <xsl:if test="$html-output">
              <xsl:value-of select="translate( 'Invoice_Joinery.xsl $Revision: 1.5 $$Date: 2003/02/12 20:59:58 $','$','')"/>
               <basic-link external-destination="http://www.CraneSoftwrights.com/links/res-ublf.htm">
                  <xsl:text>http://www.CraneSoftwrights.com/links/res-ublf.htm</xsl:text>
               </basic-link>
            </xsl:if>
         </block>
         <block id="{generate-id(/)}">
            <marker marker-class-name="cont"/>
         </block>
      </flow>
   </page-sequence>
</xsl:template>

<xsl:template match="cat:ReferencedDespatchAdvice/cat:ID">
   <block space-before="2em">
      <xsl:text>Delivery Doc: </xsl:text>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:BuyersOrderID">
   <block space-before="2em">
      <xsl:text>Your Order No: </xsl:text>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:ReferencedOrder/cat:IssueDate">
   <block>
      <xsl:text>Issue Date: </xsl:text>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:RequestedDeliveryDate">
   <block space-before="1em" space-after="1em">
      <xsl:text>
        Required Delivery on </xsl:text>
        <xsl:apply-templates/>
        Confirmed
   </block>
</xsl:template>

<xsl:template match="cat:AllowanceCharge[cat:MultiplierReasonCode='trade']">
  <block space-before="1em">
    <xsl:text>Trade Discount: </xsl:text>
    <xsl:value-of select="cat:MultiplierFactorQuantity * 100"/>
    <xsl:text>% discount will be applied to this order.</xsl:text>
  </block>
</xsl:template>

<xsl:template match="cat:InvoiceLine" mode="do-delivery">
  <block keep-with-previous="always" space-before="1em">
    <xsl:for-each select="cat:Item/cat:BasePrice/cat:PriceAmount">
      <xsl:text>A surcharge of </xsl:text>
      <xsl:value-of select="concat( @currencyID, '&#xa0;', . )"/>
      <xsl:text> will be made for delivery.</xsl:text>
    </xsl:for-each>
  </block>
</xsl:template>

<!--========================================================================-->

<!--Order line information-->

<xsl:template name="do-line-items">
   <table table-layout="fixed">
      <table-column column-width= "9mm"/>
      <table-column column-width="24mm"/>
      <table-column column-width="11mm"/>
      <table-column column-width="15mm"/>
      <table-column column-width="18mm"/>
      <table-column column-width="15mm"/>
      <table-column column-width="13mm"/>
      <table-column column-width="15mm"/>
      <table-column column-width="13mm"/>
      <table-column column-width="15mm"/>
      <table-column column-width="35mm"/>
      <table-column column-width="11mm"/>
      <table-column column-width="35mm"/>
      <table-column column-width="33mm"/>

      <!--the header is repeated at the top of each page-break in the table-->
      <table-header text-align="center" start-indent="2pt" end-indent="2pt">
         <table-row font-size="66%">
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Line</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" text-align="start" 
                        display-align="center">
               <block font-style="italic">
                  <xsl:text>Item</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Hand</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Qty</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Measure</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Measured</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Wood</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Finish</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Fittings</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
               <block font-style="italic">
                  <xsl:text>Glazing</xsl:text>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
              <block font-style="italic">
                <xsl:text>Price each</xsl:text>
              </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center"
start-indent="0pt" end-indent="0pt">
              <block font-style="italic">
                <xsl:text>Tax Category</xsl:text>
              </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
              <block font-style="italic">
                <xsl:text>Gross Price Extension</xsl:text>
              </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
              <block/>
            </table-cell>
         </table-row>
       </table-header>

      <!--the body governs the length of the table-->
      <table-body text-align="center" start-indent="2pt" end-indent="2pt">
        <xsl:variable name="line-items" 
           select="cat:InvoiceLine[ 
                   not( cat:Item/
                       cat:SellersItemIdentification/cat:ID = 'Delivery' ) ]"/>
        <xsl:variable name="delivery-item"
           select="cat:InvoiceLine
                   [ cat:Item/
                     cat:SellersItemIdentification/cat:ID = 'Delivery' ]"/>
        <xsl:variable name="gross"
          select="sum( $line-items/cat:LineExtensionAmount )"/>
        <xsl:variable name="discount"
          select="cat:AllowanceCharge/cat:MultiplierFactorQuantity"/>

        <xsl:apply-templates select="$line-items"/>

         <table-row keep-with-previous="always">
            <table-cell number-columns-spanned="11"><block/></table-cell>
            <table-cell border="solid 1pt">
              <block/>
            </table-cell>
            <table-cell border="solid 1pt">
               <block text-align="end">
                 <xsl:value-of select="format-number( $gross, '0.00' )"/>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" font-size=".8em" display-align="center">
              <block text-align="start">Gross Total</block>
            </table-cell>
         </table-row>
         <table-row keep-with-previous="always">
            <table-cell number-columns-spanned="11"><block/></table-cell>
            <table-cell border="solid 1pt">
              <block/>
            </table-cell>
            <table-cell border="solid 1pt">
               <block text-align="end">
                 <xsl:value-of 
            select="format-number( $gross - ( $gross * $discount ), '0.00' )"/>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" font-size=".8em" display-align="center">
              <block text-align="start">Less <xsl:value-of select="$discount * 100"/>% discount</block>
            </table-cell>
         </table-row>
         <table-row keep-with-previous="always">
            <table-cell number-columns-spanned="11"><block/></table-cell>
            <table-cell border="solid 1pt">
              <block>
                <xsl:value-of 
              select="$delivery-item/cat:Item/cat:Tax/cat:RateCategoryCodeID"/>
              </block>
            </table-cell>
            <table-cell border="solid 1pt">
               <block text-align="end" text-align-last="justify">
                 <xsl:for-each select="$delivery-item/cat:Item/
                                       cat:BasePrice/cat:PriceAmount">
                   <xsl:value-of select="@currencyID"/>
                   <leader/>
                   <xsl:value-of select="format-number( ., '0.00' )"/>
                 </xsl:for-each>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" font-size=".8em" display-align="center">
              <block text-align="start">Delivery Charge</block>
            </table-cell>
         </table-row>
         <table-row keep-with-previous="always">
            <table-cell number-columns-spanned="11"><block/></table-cell>
            <table-cell border="solid 1pt">
              <block/>
            </table-cell>
            <table-cell border="solid 1pt">
               <block text-align="end" text-align-last="justify">
                 <xsl:for-each 
                         select="cat:LegalTotals/cat:LineExtensionTotalAmount">
                   <xsl:value-of select="@currencyID"/>
                   <leader/>
                   <xsl:value-of select="format-number( ., '0.00' )"/>
                 </xsl:for-each>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" font-size=".8em" display-align="center">
              <block text-align="start">Total Lines + Charges</block>
            </table-cell>
         </table-row>
         <table-row keep-with-previous="always">
            <table-cell number-columns-spanned="11"><block/></table-cell>
            <table-cell border="solid 1pt">
              <block>
                <xsl:value-of 
              select="$delivery-item/cat:Item/cat:Tax/cat:RateCategoryCodeID"/>
              </block>
            </table-cell>
            <table-cell border="solid 1pt">
               <block text-align="end" text-align-last="justify">
                 <xsl:for-each 
          select="cat:TaxTotal/cat:CategoryTotal/cat:TaxAmounts/cat:TaxAmount">
                   <xsl:value-of select="@currencyID"/>
                   <leader/>
                   <xsl:value-of select="format-number( ., '0.00' )"/>
                 </xsl:for-each>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" font-size=".8em" display-align="center">
              <block text-align="start">
                <xsl:value-of select="cat:TaxTotal/cat:TaxTypeCode"/>
                at
                <xsl:value-of select="format-number( cat:TaxTotal/cat:CategoryTotal/cat:RatePercentNumeric div 100, '0.0%' )"/>
              </block>
            </table-cell>
         </table-row>
         <table-row keep-with-previous="always">
            <table-cell number-columns-spanned="11"><block/></table-cell>
            <table-cell border="solid 1pt">
              <block/>
            </table-cell>
            <table-cell border="solid 1pt">
               <block text-align="end" text-align-last="justify">
                 <xsl:for-each 
                              select="cat:LegalTotals/cat:ToBePaidTotalAmount">
                   <xsl:value-of select="@currencyID"/>
                   <leader/>
                   <xsl:value-of select="format-number( ., '0.00' )"/>
                 </xsl:for-each>
               </block>
            </table-cell>
            <table-cell border="solid 1pt" display-align="center">
              <block text-align="start">TOTAL DUE</block>
            </table-cell>
         </table-row>
      </table-body>
   </table>
</xsl:template>

<xsl:template match="cat:InvoiceLine">
  <xsl:variable name="measurements" 
    select="cat:Item/cat:SellersItemIdentification/cat:ItemMeasurement"/>
  <xsl:variable name="rows">
    <xsl:choose>
      <xsl:when test="count( $measurements ) = 0">1</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="count( $measurements )"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
    <table-row>
      <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
        <block>
          <xsl:apply-templates select="cat:ReferencedOrderLine/cat:BuyersID"/>
        </block>
      </table-cell>
      <xsl:for-each select="cat:Item/cat:SellersItemIdentification">
        <table-cell border="solid 1pt" text-align="start" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates select="cat:ID"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates 
    select="cat:PhysicalAttribute[cat:AttributeID='hand']/cat:DescriptionID"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates select="ancestor::cat:InvoiceLine/
                                         cat:InvoicedQuantity"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt">
          <block>
            <xsl:apply-templates mode="do-length-calc"
                                 select="cat:ItemMeasurement[1]"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt">
          <block>
            <xsl:apply-templates mode="do-length-measure"
                                 select="cat:ItemMeasurement[1]"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates 
     select="cat:PhysicalAttribute[cat:AttributeID='wood']/cat:DescriptionID"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates 
   select="cat:PhysicalAttribute[cat:AttributeID='finish']/cat:DescriptionID"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates 
 select="cat:PhysicalAttribute[cat:AttributeID='fittings']/cat:DescriptionID"/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
          <block>
            <xsl:apply-templates 
  select="cat:PhysicalAttribute[cat:AttributeID='glazing']/cat:DescriptionID"/>
          </block>
        </table-cell>
      </xsl:for-each>
      <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
        <xsl:apply-templates select="cat:Item/cat:BasePrice/cat:PriceAmount"/>
      </table-cell>
      <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
        <block>
          <xsl:apply-templates 
            select="cat:Item/cat:Tax/cat:RateCategoryCodeID"/>
        </block>
      </table-cell>
      <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
        <xsl:apply-templates select="cat:LineExtensionAmount"/>
      </table-cell>
      <table-cell border="solid 1pt" number-rows-spanned="{$rows}">
        <block/>
      </table-cell>
   </table-row>
   <!--accommodate multiple measurements; needs special row handling-->
   <xsl:for-each select="cat:Item/cat:SellersItemIdentification/
                         cat:ItemMeasurement[ position() > 1 ]">
     <table-row border-before-style="hidden" border-after-style="none"
                border="solid 1pt">
        <table-cell border="solid 1pt">
          <block>
            <xsl:apply-templates mode="do-length-calc" select="."/>
          </block>
        </table-cell>
        <table-cell border="solid 1pt">
          <block>
            <xsl:apply-templates mode="do-length-measure" select="."/>
          </block>
        </table-cell>
     </table-row>
   </xsl:for-each>
</xsl:template>

<xsl:template match="cat:PriceAmount | cat:LineExtensionAmount">
  <block text-align="end" text-align-last="justify">
    <xsl:value-of select="@currencyID"/>
    <leader/>
    <xsl:value-of select="format-number( ., '0.00' )"/>
  </block>
</xsl:template>

<!--========================================================================-->

<!--Length display and calculation-->

<xsl:template match="cat:ItemMeasurement" mode="do-length-measure">
  <xsl:apply-templates select="cat:AttributeID"/>
</xsl:template>

<xsl:template match="cat:ItemMeasurement" mode="do-length-calc">
  <xsl:apply-templates select="cat:Measure"/>
</xsl:template>

<xsl:template match="cat:Measure | 
               cat:InvoicedQuantity[@unitCode='feet' or @unitCode='inches']" >
  <xsl:choose>
    <xsl:when test="@unitCode='feet'">
      <xsl:value-of select="."/>ft
    </xsl:when>
    <xsl:when test="@unitCode='inches'">
      <xsl:if test=". >= 12">
        <xsl:value-of select="floor( . div 12 )"/>ft
      </xsl:if>
      <xsl:value-of select=". mod 12"/>in
    </xsl:when>
    <xsl:when test="@unitCode='centimeters'">
      <xsl:value-of select="."/>cm
    </xsl:when>
    <xsl:when test="@unitCode='millimeters'">
      <xsl:value-of select="."/>mm
    </xsl:when>
    <xsl:when test="@unitCode='meters'">
      <xsl:value-of select="."/>m
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="."/> <xsl:value-of select="@unitCode"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--========================================================================-->
<!--Address and contact information-->

<xsl:template match="cat:BuyerParty" name="name-address">
   <block>
      <xsl:apply-templates select="cat:PartyName/cat:Name"/>
      <xsl:apply-templates select="cat:Address"/>
   </block>
</xsl:template>

<xsl:template match="cat:SellerParty">
   <block>
      <xsl:call-template name="name-address"/>
   </block>
</xsl:template>

<xsl:template match="cat:DeliverToAddress">
   <block>
      <xsl:call-template name="address"/>
   </block>
</xsl:template>

<xsl:template match="cat:Address" name="address">
  <block>
    <xsl:apply-templates select="cat:Street"/>
    <xsl:apply-templates select="cat:HouseName"/>
    <block>
      <xsl:apply-templates select="cat:CityName"/>
      <xsl:apply-templates select="cat:CountrySub-Entity"/>
    </block>
    <xsl:apply-templates select="cat:Country/cat:Code"/>
    <xsl:apply-templates select="cat:PostalZone"/>
  </block>
</xsl:template>

<xsl:template match="cat:BuyerParty/cat:BuyerContact/cat:Name">
   <block>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:CityName">
   <inline>
      <xsl:apply-templates/>
   </inline>
</xsl:template>

<xsl:template match="cat:Country/cat:Code">
   <block>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:CountrySub-Entity">
   <inline>
      <xsl:text>, </xsl:text>
      <inline>
         <xsl:apply-templates/>
      </inline>
   </inline>
</xsl:template>

<xsl:template match="cat:PartyName/cat:Name">
   <block>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:PostalZone">
   <block>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:Street">
   <block>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:HouseName">
   <block>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<!--========================================================================-->

<!--Marginalia-->

<xsl:template name="before-edge-marginalia">
   <static-content flow-name="before">
      <block font-weight="bold" text-align-last="justify">
         <xsl:text>JOINERY INVOICE</xsl:text>
         <xsl:if test="not($html-output)">
           <leader/>
           <xsl:text>Page </xsl:text>
           <page-number/>
           <xsl:text> of </xsl:text>
           <page-number-citation ref-id="{generate-id(/)}"/>
         </xsl:if>
      </block>
      <table table-layout="fixed" width="100%"
             space-before.conditionality="retain" space-before="1em">
        <table-column column-width="72%"/>
        <table-column column-width="26%"/>
        <table-body>
          <table-row>
            <table-cell>
              <block/>
            </table-cell>
            <table-cell>
              <xsl:apply-templates select="cat:ID" mode="header-info"/>
              <xsl:apply-templates select="cat:IssueDate" mode="header-info"/>
            </table-cell>
          </table-row>
        </table-body>
      </table>
   </static-content>
</xsl:template>

<xsl:template match="cat:ID" mode="header-info">
   <block>
      <xsl:text>Invoice No: </xsl:text>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template match="cat:IssueDate" mode="header-info">
   <block>
     <xsl:text>Invoice Date/Tax Point: </xsl:text>
      <xsl:apply-templates/>
   </block>
</xsl:template>

<xsl:template name="start-edge-marginalia">
   <static-content flow-name="start">
      <block-container display-align="after">
         <block-container reference-orientation="90" display-align="after"
                          width="183mm - 10mm">
<!--meta data for this form in print-->
            <block font-family="Arial" font-size="6pt" text-indent="2mm" 
                   space-after="2pt" space-after.conditionality="retain">
               <xsl:if test="not($html-output)">
                 <xsl:value-of select="translate( 'Invoice_Joinery.xsl $Revision: 1.5 $$Date: 2003/02/12 20:59:58 $','$','')"/>
                  <basic-link 
     external-destination="http://www.CraneSoftwrights.com/links/res-ublf.htm">
                     <xsl:text>http://www.CraneSoftwrights.com/links/res-ublf.htm</xsl:text>
                  </basic-link>
               </xsl:if>
            </block>
         </block-container>
         <block>
            <block text-align="end" font-weight="bold" 
                   font-family="Arial" font-size="7pt" end-indent="2pt">
               <xsl:text>JOIN-</xsl:text>
            </block>
            <block text-align="end" font-weight="bold" 
                   font-family="Arial" font-size="7pt" end-indent="2pt">
               <xsl:text>INV</xsl:text>
            </block>
         </block>
      </block-container>
   </static-content>
</xsl:template>

<xsl:template name="after-edge-marginalia">
   <static-content flow-name="after">
      <block text-align="end" font-style="italic">
         <retrieve-marker retrieve-class-name="cont" retrieve-position="last-starting-within-page"/>
      </block>
   </static-content>
</xsl:template>

</xsl:stylesheet>

