# Common routines for working on the UBL stylesheet script instance
#
# $Id: common.py,v 1.8 2003/02/10 01:59:45 G. Ken Holman Exp $

usage = """
Usage:  [-option]* scriptXML [optional-document-type]*

Options:
         -e      = echo
         -nobeep = no beeping if an error encountered
"""

"""
Copyright (C) - Crane Softwrights Ltd. 
              - http://www.CraneSoftwrights.com/links/res-ubl.htm

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright notice, 
  this list of conditions and the following disclaimer. 
- Redistributions in binary form must reproduce the above copyright notice, 
  this list of conditions and the following disclaimer in the documentation 
  and/or other materials provided with the distribution. 
- The name of the author may not be used to endorse or promote products 
  derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN 
NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

false = 0
true = not( false )
import sys
from xml.sax import SAXParseException
from xml.dom.minidom import parse, Attr
from run import doDocType
from runos import setflags

def exit( reason=None ): #all error exits should have a reason to display
    if reason:
        sys.stderr.write( "%s\n" % reason )
        sys.stderr.write( "Aborted exit...\n" )
        sys.exit(1)
    sys.exit(0)

def getInputs( docTypeElem ):
    prefix = ""
    inputs = []
    notdiags = []
    layouts = []
    literates = []
    
    for ( attr, value ) in docTypeElem.attributes.items():
        if attr == "nsprefix":
            prefix = value

    for inputElem in docTypeElem.getElementsByTagName( "LayoutXSLT" ):
        layout = ""
        literate = false
        for ( attr, value ) in inputElem.attributes.items():
            if attr == "baseurl":
                layout = value
            elif attr == "literate":
                literate = true
        layouts = layouts + [ layout ]
        if literate:
            literates = literates + [ layout ]

    for inputElem in docTypeElem.getElementsByTagName( "TestInputXML" ):
        input = ""
        skipkey = false
        for ( attr, value ) in inputElem.attributes.items():
            if attr == "baseurl":
                input = value
            elif attr == "diag" and value == "yes":
                skipkey = true
        inputs = inputs + [ input ]
        if not( skipkey ):
            notdiags = notdiags + [ input ]

    return( layouts, literates, inputs, notdiags, prefix )

#=========================================================================
#
# Argument processing

echo = false
badopt = false
nobeep = false

while len( sys.argv ) > 1 and \
      ( sys.argv[1][0] == '/' or sys.argv[1][0] == '-' ):
    opt = sys.argv[1][1:]
    if opt == 'e':  echo = true
    elif opt == 'nobeep':  nobeep = true
    else:
        print( 'Option "%s" not recognized' % opt )
        badopt = true
    sys.argv[ 1:2 ] = []

if len( sys.argv ) < 2 or badopt: # cannot proceed as requested by user
    sys.stderr.write( usage )
    sys.exit(1)

try: # opening the input file
    fileIn = open( sys.argv[1], "r" )
except IOError, (errno, strerror):
    sys.stderr.write( "I/O error(%s): %s" % (errno, strerror) )
    sys.exit(1)
except:
    sys.stderr.write( "Unexpected error: see output file for details" )
    print sys.exc_info()[0]
    sys.exit(1)

sys.argv[ 0:2 ] = [] #remove program name and script name

setflags( nobeep )

#=============================================================================
#
# Main logic

try: # processing the input file into a DOM structure
    dom = parse( fileIn )
except IOError, (errno, strerror):
    exit( "I/O error(%s): %s: %s" % (errno, strerror, file) )
except SAXParseException:
    exit( "File does not parse as well-formed XML: %s" % file )

allDocTypes = dom.documentElement.getElementsByTagName( "DocumentType" )

for docTypeElem in allDocTypes:
    for ( attr, value ) in docTypeElem.attributes.items():
        if attr == 'id':
            if len( sys.argv ) == 0 or value in sys.argv:
                doDocType( echo, value, docTypeElem )

# end of file

