# Driver for UBL stylesheet execution with data files
# $Id: run.py,v 1.16 2003/02/10 01:59:45 G. Ken Holman Exp $

"""
Copyright (C) - Crane Softwrights Ltd. 
              - http://www.CraneSoftwrights.com/links/res-ubl.htm

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright notice, 
  this list of conditions and the following disclaimer. 
- Redistributions in binary form must reproduce the above copyright notice, 
  this list of conditions and the following disclaimer in the documentation 
  and/or other materials provided with the distribution. 
- The name of the author may not be used to endorse or promote products 
  derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN 
NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

import os
import common
from runos import *
from common import *
from xml.dom.minidom import parse, Attr

#=============================================================================
#
# A single document type

def doDocType( echo, doctype, docTypeElem ):
    print ftime()+"Acting on: %s ..." % doctype
    savecwd = os.getcwd()
    try: os.chdir( doctype )
    except OSError, (errno, strerror):
        exit( errno, "O/S error(%s): %s: %s" % (errno, strerror, doctype ) )
    
    ( layouts, literates, inputs, notdiags, prefix ) \
                                              = common.getInputs( docTypeElem )

    for layout in layouts:
        try: os.chdir( layout )
        except OSError, (errno, strerror):
            exit( errno, "O/S error(%s): %s: %s" % (errno, strerror, layout ) )
        
        for input in inputs:
            if input in notdiags: # then a simple input file
                print ftime()+"Creating test result fo/%s.%s.fo ..." \
                      % ( layout, input )
                runxslt( echo, "../xml/"+input+".xml", layout+".xsl",
                         "fo/"+layout+"."+input+".fo" )
                print ftime()+"Creating test print pdf/%s.%s.pdf ..." \
                      % ( layout, input )
                runxslfo( echo, "fo/"+layout+"."+input+".fo",
                                "pdf/"+layout+"."+input+".pdf" )
                print ftime()+"Creating test result US fo/%s.%s-us.fo ..." \
                      % ( layout, input )
                runxslt( echo, "../xml/"+input+".xml", layout+"-us.xsl",
                         "fo/"+layout+"."+input+"-us.fo" )
                print ftime()+"Creating test print US pdf/%s.%s-us.pdf ..." \
                      % ( layout, input )
                runxslfo( echo, "fo/"+layout+"."+input+"-us.fo",
                                "pdf/"+layout+"."+input+"-us.pdf" )
                print ftime()+"Creating test result intermediate "+ \
                              "fo/%s.%s.html.fo ..." % ( layout, input )
                runxslt( echo, "../xml/"+input+".xml",layout+"-htmlfo.xsl",
                         "fo/"+layout+"."+input+".html.fo" )
                print ftime()+"Creating HTML result "+ \
                              "html/%s.%s.html ..." % ( layout, input )
                runxslt( echo, "fo/"+layout+"."+input+".html.fo",
                               "../../util/fo2html.xsl",
                               "html/"+layout+"."+input+".html" )
#               print ftime()+"Deleting intermediate "+ \
#                             "fo/%s.%s.html.fo ..." % ( layout, input )
#               os.remove( "fo/%s.%s.html.fo" % ( layout, input ) )

        os.chdir( ".." )

    if os.access( "debug/%s.xml" % ( doctype ), os.F_OK ):
        os.chdir( "debug" )
        for input in inputs:
            if input not in notdiags:
                for layout in layouts:
                    print ftime()+"Creating test result fo/%s.fo ..." \
                          % ( layout )
                    runxslt( echo, input+".xml",
                                   "../%s/%s.xsl" % ( layout, layout ),
                                   "fo/"+layout+".fo" )
                    print ftime()+"Creating test print %s.pdf ..." \
                                   % ( layout )
                    runxslfo( echo, "fo/"+layout+".fo",
                                    layout+".pdf" )
                    print ftime()+"Creating test result US fo/%s-us.fo ..."\
                                  % ( layout )
                    runxslt( echo, input+".xml",
                                   "../%s/%s-us.xsl" % ( layout, layout ),
                                   "fo/"+layout+"-us.fo" )
                    print ftime()+"Creating test print US %s-us.pdf ..." \
                                  % ( layout )
                    runxslfo( echo, "fo/"+layout+"-us.fo",
                                    layout+"-us.pdf")
                    print ftime()+"Creating test result intermediate "+ \
                                  "fo/%s.html.fo ..." % ( layout )
                    runxslt( echo, input+".xml",
                                   "../%s/%s-htmlfo.xsl" % ( layout, layout ),
                                   "fo/"+layout+".html.fo" )
                    print ftime()+"Creating HTML result "+ \
                                  "%s.html ..." % ( layout )
                    runxslt( echo, "fo/"+layout+".html.fo",
                                   "../../util/fo2htmlk.xsl",
                                   layout+".html",
                                   { 'keyhtml': doctype+".key.rpt.html",
                                     'keyxml': "../"+doctype+".xml",
                                     'nsprefix': prefix,
                                     'offset':'0'} )
        
#               print ftime()+"Creating test result %s.html ..." % input
#               runxslt( echo, input+".html.fo", "../../util/fo2html.xsl",
#                        "../"+input+".html" )
#               print ftime()+"Creating keyed test result %s.key.fo ..." \
#                     % input
#               runxslt( echo, input+".key.xml", "../"+doctype+".xsl",
#                        input+".key.fo" )
#               print ftime()+"Creating keyed print %s.key.pdf ..." % input
#               runxslfo( echo, input+".key.fo", input+".key.pdf" )
#               print ftime()+"Creating keyed test result intermediate "+\
#                     "%s.html.fo ..." % input
#               runxslt( echo, input+".key.xml", "../"+doctype+"-htmlfo.xsl",
#                        input+".key.html.fo" )
#               print ftime()+"Creating keyed test result intermediate "+\
#                     "%s.key.html ..." % input
#               runxslt( echo, input+".key.html.fo", "../../util/fo2htmlk.xsl",
#                        input+".key.html",
#                          { 'keyhtml': input+".key.rpt.html",
#                            'keyxml': input+".xml",
#                            'nsprefix': prefix,
#                            'offset':'0'})
#       else: # a special already-keyed input file
#           print ftime()+"Creating keyed test result intermediate "+\
#                         "%s.key.html ..." % input
#           runxslt( echo, input+".html.fo", "../../util/fo2htmlk.xsl",
#                          input+".key.html",
#                          { 'keyhtml': input+".key.rpt.html",
#                            'keyxml': input+".xml",
#                            'nsprefix': prefix,
#                            'offset':'0'})

    os.chdir( savecwd )

# end of file
