# O/S and applciation dependent functions and procedures for UBL stylesheets
# $Id: runos.py,v 1.8 2003/01/10 18:37:33 G. Ken Holman Exp $

"""
Copyright (C) - Crane Softwrights Ltd. 
              - http://www.CraneSoftwrights.com/links/res-ubl.htm

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright notice, 
  this list of conditions and the following disclaimer. 
- Redistributions in binary form must reproduce the above copyright notice, 
  this list of conditions and the following disclaimer in the documentation 
  and/or other materials provided with the distribution. 
- The name of the author may not be used to endorse or promote products 
  derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN 
NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

import sys
import os
import fileinput
import re
import shutil

from time import *
from stat import *

#=============================================================================
# generic routines (should be O/S and environment independent)

otherrun = "missing name for other file"
false = 0
true  = not false
nobeep = false

def setflags( nobeepflag ):
    nobeep = nobeepflag

def ftime():
    return( strftime( '%H:%M:%S ' ) )

def runbeep():
    if not nobeep: print "",
    return ""

def pressEnter():
    print ftime()+'Press enter only to continue...'+runbeep()
    try: enter = sys.stdin.readline()
    except KeyboardInterrupt:
        sys.exit( 1 )
    if len(enter) != 1:
        sys.exit( 1 )
    print ftime()+'Continuing...'
    
def exit( ret, msg ):
    if ret:
        print "Exit "+ftime()+runbeep()+" (%d):\n"% ret + msg
    sys.exit( ret )

def delete( path ):
    if os.access( path, os.F_OK ):
        try:
            os.remove( path )
        except OSError:
            return 1
    return 0

def delete_retry( path ):
    while delete( path ):
        print 'Unable to delete '+path+'... locked in an application?'
        pressEnter()

def deletetree( path ):
    try:
        shutil.rmtree( path )
    except OSError, (errno, strerror):
        exit( 1, "I/O error(%s): %s" % (errno, strerror ) )
    return 0

def run_exit( command, ret, showerr=true ):
    if os.access( 'run.err', os.F_OK ) and \
       os.stat('run.err')[ST_SIZE] and showerr:
        typefile = open( 'run.err', 'r' )
        for line in typefile.readlines():
            print line,
        typefile.close()
        exit( ret, command )
    sys.exit(ret)

def runraw( echo, command, cleanup ):
    if echo:
        print command
    try:
        ret = os.system( command )
    except KeyboardInterrupt:
        ret = 1
    if ret and ret != 18:  #18 seems to be magic for WinNT for busy file
        #if cleanup: delete( cleanup ) ??? doesn't make sense!
        run_exit( command, ret )
    if ret == 0 and \
       os.access('run.err', os.F_OK ) and os.stat('run.err')[ST_SIZE] == 0:
        delete( 'run.err' )
    return ( ret )

def removewildcard( path ):
    while 1:
        try:
            os.remove( path )
        except:
            print 'Unable to delete '+path+'... locked in an application?'
            pressEnter()
            continue
        break

def run( echo, command ):
    return( runraw( echo, command, None ) )

#=============================================================================
# Invocations of applications 

# This is only used in the development of the stylesheet library, not using it.
# Jing is found at: http://www.thaiopensource.com/relaxng/jing.html
def runrelaxngc( echo, model, source ):
    command = "jing -c "+model+" "+source+" >run.err"
    return( run( echo, command ) )

# This runs an XSLT processor with the given stylesheet on the given source
# Saxon can be found at http://saxon.sourceforge.net
def runxslt( echo, source, stylesheet, result=None, parameters={} ):
    if result:
        useResult = result
    else:
        useResult = source+".nullXSLT"
        delete( useResult )
    params = ''
    for parameter in parameters.keys():
        params = params + ' "' + parameter +\
                 '=' + parameters[parameter] + '"'
    command = 'saxon -o '+useResult+' '+source+' '+stylesheet+' '+params+\
              ' 2>run.err'
    ret = runraw( echo, command, None )
    if not( result ):
        delete( useResult )
    if os.access('run.err', os.F_OK ):
        run_exit( command, 1 )
    return( ret )

# This runs a PDF distiller with the given PostScript file
# GhostScript can be found at http://www.GhostScript.com
def runps2pdf( echo, ps, pdf ):
    print ftime()+'Converting PostScript to PDF: "'+pdf+'"...'
    delete_retry( pdf )
    run( echo, 'gswin32c -dBATCH -dNOPAUSE -q -dSAFER '+
         '-sDEVICE=pdfwrite -sOutputFile='+pdf+' '+
         '-c .setpdfwrite -f '+ps+' >run.err' )

# This runs an XSL-FO engine with the given XSL-FO instance to PDF
# XEP can be found at http://www.RenderX.com
# Antenna House can be found at http://www.AntennaHouse.com
def runxslfo( echo, fo, pdf ):

    ps = fo+".ps"

    renderx = 0
    axfo = 1

    if renderx:
        print ftime()+"Composing with XEP to PostScript..."
        command = 'java 2>run.err -Xms20m -Xmx500m -classpath "'+\
                  os.environ['XEP_CP-PS']+\
                  '" "-Dcom.renderx.xep.ROOT='+os.environ['XEP_HOME']+\
                  '" -Dcom.renderx.xep.VALIDATE=false'+\
       ' -Dcom.renderx.xep.OUTPUT_PRODUCER=com.renderx.xep.gen.backends.H4PS'+\
                  ' com.renderx.xep.Driver '+ fo
        run( echo, command )
        processingError = false
        if os.access( 'run.err', os.F_OK ):
            for lineIn in fileinput.input( 'run.err' ):
                if re.search( "\\{(\\?[^s]|!)", lineIn ):
                    print lineIn,
                    processingError = true
        if processingError:
            run_exit( command, 1, false )
        runps2pdf( echo, ps, pdf )

    if axfo:
        print ftime()+"Composing with Antenna House to PostScript..."
        command = 'axfocmd -d '+fo+' -o '+ps+' >run.err'
        ret = run( echo, command )
        if not ret:
            if os.access( 'run.err', os.F_OK ):
                for lineIn in fileinput.input( 'run.err' ):
                    if re.search( "Error", lineIn ):
                        ret = 1
                        break
        runps2pdf( echo, ps, pdf )

    # remove any remnant of a prior formatting attempt
    delete_retry( ps )

# end of file
