<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:ss="http://www.CraneSoftwrights.com/ns/ubl-stylesheets"
  xmlns:fo="http://www.w3.org/1999/XSL/Format"
  exclude-result-prefixes="ss fo"
                version="1.0">

<!--$Id: fo2htmlk.xsl,v 1.5 2003/01/31 20:19:09 G. Ken Holman Exp $-->
<!--intercept FO text nodes when creating HTML and inject hyperlinks-->

<!--
Consider adding:

 onMouseOver="window.status=&quot;status-line-text-here&quot;;return true"
 onClick="clipboardData.setData( 'Text',&quot;clipboard-text-here&quot; );
          window.status=&quot;status-line-text-here&quot;;
          return true" 
 onMouseOut="window.status='';return true"

-->

<xsl:import href="fo2html.xsl"/>

<xsl:param name="keyhtml"/>
<xsl:param name="keyxml"/>
<xsl:param name="nsprefix"/>
<xsl:param name="offset" select="0"/>

<xsl:variable name="ss:debug-work">
  <xsl:if test="not($keyhtml)">
    Error
    <xsl:message>Missing keyhtml= parameter for file of key info</xsl:message>
  </xsl:if>
  <xsl:if test="not($keyxml)">
    Error
    <xsl:message>Missing keyxml= parameter for file of key data</xsl:message>
  </xsl:if>
</xsl:variable>

<xsl:variable name="ss:debug-exit">
  <xsl:if test="string($ss:debug-work)">
    <xsl:message terminate="yes">
      <xsl:text>Exiting with errors.</xsl:text>
    </xsl:message>
  </xsl:if>
</xsl:variable>

<xsl:template match="text()" mode="check-for-pre">
  <xsl:call-template name="ss:xlate-link"/>
</xsl:template>

<xsl:template match="text()" name="ss:xlate-link" priority="10">
  <xsl:param name="text" select="."/>

  <xsl:choose>
    <xsl:when test="contains( $text, '!' )">
      <xsl:value-of select="substring-before( $text, '!' )"/>
      <xsl:variable name="remain" select="substring-after( $text, '!' )"/>
      <xsl:choose>
        <xsl:when test="not( contains( $remain, '!' ) )">
          <xsl:value-of select="$remain"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="ss:do-link">
            <xsl:with-param name="key" select="substring-before($remain,'!')"/>
          </xsl:call-template>
          <xsl:call-template name="ss:xlate-link">
            <xsl:with-param name="text" select="substring-after($remain,'!')"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$text"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:key name="ss:keys" match="text()[normalize-space(.)]|@*" 
                        use="translate(.,'!','')"/>

<xsl:template name="ss:do-link">
  <xsl:param name="key"/>
  <xsl:variable name="path">
    <xsl:for-each select="document( $keyxml, . )">
      <xsl:for-each select="key( 'ss:keys', $key )">
        <xsl:for-each select="ancestor-or-self::*">
          <xsl:text>/</xsl:text>
          <xsl:variable name="name" select="name(.)"/>
          <xsl:if test="not( contains( $name, ':' ) )">
            <xsl:value-of select="concat( $nsprefix, ':' )"/>
          </xsl:if>
          <xsl:value-of select="$name"/>
        </xsl:for-each>
      </xsl:for-each>
      <xsl:if test="name(.)">
        <xsl:value-of select="concat( '/@', name(.) )"/>
      </xsl:if>
    </xsl:for-each>
  </xsl:variable>

  <a target="key" 
     onMouseOver="window.status=&quot;{$path}&quot;;return true"
     onMouseOut="window.status='';return true"
     onclick="clipboardData.setData( 'Text',&quot;{$path}&quot; );
              window.status=&quot;Clipboard: {$path}&quot;;
              window.open('','key').focus();"
     href="{$keyhtml}#key-{floor( $key ) - number($offset)}">
    <xsl:text/>!<xsl:value-of select="$key"/>!<xsl:text/>
  </a>

</xsl:template>

</xsl:stylesheet>


